---
title: <span class="badge object-type-scalar"></span> MegabytesPerSecond
---
# <span class="badge object-type-scalar"></span> MegabytesPerSecond

Data rate: megabytes/sec

## Definition

```python
# Data rate: megabytes/sec
MegabytesPerSecond: typing.Literal["MBs"] = "MBs"
```
